package fortedit;

import java.awt.Dimension;
import java.awt.event.InputEvent;
import java.awt.event.KeyEvent;
import java.awt.event.WindowEvent;
import java.awt.event.WindowListener;
import java.util.Map;
import java.util.TreeMap;

import javax.swing.*;

import fortedit.editeur.Editeur;
import fortedit.mondes.Monde;

public class Fenetre extends JFrame{
	private static final long serialVersionUID = 1L;
    private Editeur editeur;
    private Map<Monde, JRadioButtonMenuItem> menuEditionMondesBouton = new TreeMap<Monde, JRadioButtonMenuItem>();

    public Fenetre() {
        setTitle("Nouvelle Carte - diteur de cartes pour Forteresse");
        setDefaultCloseOperation(JFrame.DO_NOTHING_ON_CLOSE);
        this.addWindowListener(new FenetreClose(this));
        setPreferredSize(new Dimension(1000, 750));

        setEditeur(new Editeur(this));
        this.setContentPane(getEditeur());

        JMenuBar menuBar = new JMenuBar();

        JMenu menuFichier = new JMenu("Fichier");
            JMenuItem nouvelleCarte = new JMenuItem(new FenetreConfirmation(this,new CarteNouvelle(this)));
            nouvelleCarte.setText("Nouvelle carte");
            getEditeur().getInputMap().put(KeyStroke.getKeyStroke("ctrl N"), "ctrl N");
            getEditeur().getActionMap().put("ctrl N", nouvelleCarte.getAction());
            nouvelleCarte.setToolTipText("ctrl N");
            menuFichier.add( nouvelleCarte);

            JMenuItem ouvrirCarte = new JMenuItem(new FenetreConfirmation(this,new CarteLoad(this)));
            ouvrirCarte.setText("Ouvrir");
            getEditeur().getInputMap().put(KeyStroke.getKeyStroke("ctrl O"), "ctrl O");
            getEditeur().getActionMap().put("ctrl O", ouvrirCarte.getAction());
            ouvrirCarte.setToolTipText("ctrl O");
            menuFichier.add(ouvrirCarte);

            JMenuItem enregistrer = new JMenuItem(new CarteSave(this, "Enregistrer"));
            getEditeur().getInputMap().put(KeyStroke.getKeyStroke(KeyEvent.VK_S , InputEvent.CTRL_MASK), "ctrl S");
            getEditeur().getActionMap().put("ctrl S", enregistrer.getAction());
            enregistrer.setToolTipText("ctrl S");
            menuFichier.add(enregistrer);

            JMenuItem enregistrerSous = new JMenuItem(new CarteSaveSous(this, "Enregistrer sous"));
            menuFichier.add(enregistrerSous);

            JMenuItem exporter = new JMenuItem(new CarteExporter(editeur, "Exporter"));
            getEditeur().getInputMap().put(KeyStroke.getKeyStroke("ctrl E"), "ctrl E");
            getEditeur().getActionMap().put("ctrl E", exporter.getAction());
            exporter.setToolTipText("ctrl E");
            menuFichier.add(exporter);

            menuFichier.addSeparator();

            JMenuItem quitter = new JMenuItem(new FenetreConfirmation(this, new FenetreQuitter()));
            quitter.setText("Quitter");
            getEditeur().getInputMap().put(KeyStroke.getKeyStroke("ctrl Q"), "ctrl Q");
            getEditeur().getActionMap().put("ctrl Q", quitter.getAction());
            quitter.setToolTipText("ctrl Q");
            menuFichier.add(quitter);
        menuBar.add(menuFichier);

        JMenu menuEdition = new JMenu("dition");
            JMenuItem annuler = new JMenuItem(new CarteEditeurAnnuler(editeur));
            annuler.setText("Annuler");
            menuEdition.add(annuler);
            getEditeur().getInputMap().put(KeyStroke.getKeyStroke("ctrl Z"), "ctrl Z");
            getEditeur().getActionMap().put("ctrl Z", annuler.getAction());
            annuler.setToolTipText("ctrl Z");

            JMenuItem repeter = new JMenuItem(new CarteEditeurRepeter(editeur));
            repeter.setText("Rpter");
            menuEdition.add(repeter);
            getEditeur().getInputMap().put(KeyStroke.getKeyStroke("ctrl Y"), "ctrl Y");
            getEditeur().getActionMap().put("ctrl Y", repeter.getAction());
            repeter.setToolTipText("ctrl Y");
            
           menuEdition.addSeparator();

           JCheckBox mode = new JCheckBox(editeur.getImage().getSwitchLibreAction());
           mode.setText("Dessin libre");
           menuEdition.add(mode);

           menuEdition.addSeparator();

            JMenu menuEditionMondes=new JMenu("Monde");
            ButtonGroup buttonGroup = new ButtonGroup();
            JRadioButtonMenuItem buttonMenuItem;
            for (Monde monde : Monde.values()) {
            	buttonMenuItem = new JRadioButtonMenuItem("monde " + monde.getCode());
            	buttonMenuItem.addActionListener(new CarteEditeursetMonde(editeur, monde));
            	buttonGroup.add(buttonMenuItem);
            	menuEditionMondesBouton.put(monde, buttonMenuItem);
            	menuEditionMondes.add(buttonMenuItem);
            }
            menuEditionMondesBouton.get(editeur.getCartes().getCurrent().getMonde()).setSelected(true);
            
            menuEdition.add(menuEditionMondes);

            JMenuItem convertir = new JMenuItem(new CarteEditeurConvertirFenetre(this.getEditeur()));
            convertir.setText("Convertir");
            menuEdition.add(convertir);

            JMenuItem intervertir = new JMenuItem(new CarteEditeurIntervertirFenetre(this.getEditeur()));
            intervertir.setText("Intervertir");
            menuEdition.add(intervertir);

            menuEdition.addSeparator();

            JMenuItem changerSens = new JMenuItem(new CarteEditeurChangerSens(this.getEditeur()));
            changerSens.setText("Changer de sens");
            menuEdition.add(changerSens);

            JMenuItem symetriser = new JMenuItem(new CarteEditeurSymetriserFenetre(this.getEditeur()));
            symetriser.setText("Symtriser");
            menuEdition.add(symetriser);
        menuBar.add(menuEdition);

        JMenu menuAffichage = new JMenu("Affichage");
            JCheckBox temp = new JCheckBox(editeur.getImage().getSwitchFondAction());
            temp.setText("Zones");
            temp.setSelected(this.getEditeur().getImage().zones);
            menuAffichage.add(temp);
            temp=new JCheckBox(editeur.getImage().getSwitchFondAction());
            temp.setText("Monde");
            temp.setSelected(this.getEditeur().getImage().fond);
            menuAffichage.add(temp);
            menuAffichage.addSeparator();
            temp=new JCheckBox(editeur.getImage().getSwitchGrilleAction());
            temp.setText("Grille");
            temp.setSelected(this.getEditeur().getImage().grille);
            menuAffichage.add(temp);
            temp=new JCheckBox(editeur.getImage().getSwitchMireAction());
            temp.setText("Mire");
            temp.setSelected(this.getEditeur().getImage().mire);
            menuAffichage.add(temp);
            menuAffichage.addSeparator();
            temp=new JCheckBox(editeur.getImage().getSwitchZoomAction());
            temp.setText("Vue d'ensemble");
            menuAffichage.add(temp);
        menuBar.add(menuAffichage);

        JMenu menuAide = new JMenu("?");
            JMenuItem apropos = new JMenuItem(new FenetreAPropos(this));
            apropos.setText(" Propos");
            menuAide.add(apropos);
        menuBar.add(menuAide);

        setJMenuBar(menuBar);

        pack();
    }

	public void setEditeur(Editeur editeur) {
		this.editeur = editeur;
	}

	public Editeur getEditeur() {
		return editeur;
	}

	public Map<Monde, JRadioButtonMenuItem> getMenuEditionMondesBouton() {
		return menuEditionMondesBouton;
	}
}

class FenetreClose implements WindowListener {
	private FenetreConfirmation fenetreConfirmation;
	
	public FenetreClose(Fenetre fenetre) {
		fenetreConfirmation = new FenetreConfirmation(fenetre, new FenetreQuitter());
	}

	public void windowActivated(WindowEvent arg0) { }

	public void windowClosed(WindowEvent arg0) { }

	public void windowClosing(WindowEvent arg0) {
		fenetreConfirmation.actionPerformed(null);
	}

	public void windowDeactivated(WindowEvent arg0) { }

	public void windowDeiconified(WindowEvent arg0) { }

	public void windowIconified(WindowEvent arg0) { }

	public void windowOpened(WindowEvent arg0) { }
}